@@ -52,10 +52,10 @@
 #include <stdlib.h>
 
 /*
- * This release (4.7.4) is backward compatible with the
- * 4.0.x, 4.1.x, 4.2.x, 4.3.x, 4.4.x, 4.5.x, 4.6.x, 4.7,
- * 4.7.1, 4.7.2, and 4.7.3 releases.  It, of course, is
- * compatible with itself.
+ * This release (4.8.4) is backward compatible with the
+ * 4.0.x, 4.1.x, 4.2.x, 4.3.x, 4.4.x, 4.5.x, 4.6.x, 4.7.x,
+ * 4.8, 4.8.1, 4.8.2, and 4.8.3 releases.  It, of course,
+ * is compatible with itself.
  */
 static char *compatible_version[] = {
     "4.0", "4.0.1", "4.1", "4.1.1", "4.1.2", "4.1.3",
@@ -63,7 +63,9 @@ static char *compatible_version[] = {
     "4.5", "4.5.1",
     "4.6", "4.6.1", "4.6.2", "4.6.3", "4.6.4", "4.6.5",
     "4.6.6", "4.6.7", "4.6.8",
-    "4.7", "4.7.1", "4.7.2", "4.7.3", PR_VERSION
+    "4.7", "4.7.1", "4.7.2", "4.7.3", "4.7.4", "4.7.5",
+    "4.7.6",
+    "4.8", "4.8.1", "4.8.2", "4.8.3", PR_VERSION
 };
 
 /*
@@ -78,12 +80,12 @@ static char *incompatible_version[] = {
     "3.0", "3.0.1",
     "3.1", "3.1.1", "3.1.2", "3.1.3",
     "3.5", "3.5.1",
-    "4.7.9",
-    "4.8", "4.8.1",
+    "4.8.9",
+    "4.9", "4.9.1",
     "10.0", "11.1", "12.14.20"
 };
 
-int main()
+int main(int argc, char **argv)
 {
     int idx;
     int num_compatible = sizeof(compatible_version) / sizeof(char *);
